/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.area.plot;

import java.beans.IntrospectionException;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.area.AreaEventKey;
import nl.cloudfarming.client.area.AreaService;
import nl.cloudfarming.client.geoviewer.Category;
import nl.cloudfarming.client.geoviewer.ObjectLayer;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventBus;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventListener;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra
 */
public class PlotLayer extends ObjectLayer<PlotLayerObject> {

    public PlotLayer(String nodeNameKey) {
        super(new PlotPalette(), Category.AREA, NbBundle.getMessage(PlotLayer.class, nodeNameKey), true);
        initializePLots();
        GuiEventBus.addListener(new UpdatedPlotsEventListener());
    }

    class UpdatedPlotsEventListener implements GuiEventListener{

        @Override
        public void onEvent(GuiEvent event) {
            initializePLots();
        }

        @Override
        public boolean listensTo(GuiEventKey guiEventKey) {
            return AreaEventKey.PLOTS_IMPORTED.equals(guiEventKey);
        }

        @Override
        public String getModuleName() {
            return "area-plot";
        }

    }

    private void initializePLots(){
      if (getObjects().size() > 0) {
            clearObjects();
        }

        List<PlotLayerObject> objects = new ArrayList<PlotLayerObject>();

        AreaService areaService = new PlotAreaService();
        for (Plot plot : areaService.findAllPlots()) {
            try {
                objects.add(new PlotLayerObject(plot));
            } catch (IntrospectionException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        addObjects(objects);
    }

}
